﻿using Microsoft.UI.Xaml;
using Microsoft.UI.Xaml.Controls;
using Microsoft.UI.Xaml.Navigation;
using Microsoft.UI.Xaml.Media.Animation;

namespace TestProject
{
    /// <summary>
    /// 상세 페이지
    /// </summary>
    public sealed partial class DetailPage : Page
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Property
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 현재 커스텀 데이터 객체 - CurrentCustomDataObject

        /// <summary>
        /// 현재 커스텀 데이터 객체
        /// </summary>
        public CustomDataObject CurrentCustomDataObject { get; set; }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - DetailPage()

        /// <summary>
        /// 생성자
        /// </summary>
        public DetailPage()
        {
            InitializeComponent();

            this.goBackButton.Loaded += goBackButton_Loaded;
            this.goBackButton.Click  += goBackButton_Click;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Protected

        #region 탐색되는 경우 처리하기 - OnNavigatedTo(e)

        /// <summary>
        /// 탐색되는 경우 처리하기
        /// </summary>
        /// <param name="e">이벤트 인자</param>
        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
            base.OnNavigatedTo(e);

            CurrentCustomDataObject = e.Parameter as CustomDataObject;

            ConnectedAnimation animation = ConnectedAnimationService.GetForCurrentView().GetAnimation("ForwardConnectedAnimation");

            if(animation != null)
            {
                animation.TryStart(this.detailImage, new UIElement[] { this.detailStackPanel });
            }
        }

        #endregion
        #region 탐색하는 경우 처리하기 - OnNavigatingFrom(e)

        /// <summary>
        /// 탐색하는 경우 처리하기
        /// </summary>
        /// <param name="e">이벤트 인자</param>
        protected override void OnNavigatingFrom(NavigatingCancelEventArgs e)
        {
            base.OnNavigatingFrom(e);

            ConnectedAnimationService.GetForCurrentView().PrepareToAnimate("BackConnectedAnimation", this.detailImage);
        }

        #endregion

        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Go Back 버튼 로드시 처리하기 - goBackButton_Loaded(sender, e)

        /// <summary>
        /// Go Back 버튼 로드시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void goBackButton_Loaded(object sender, RoutedEventArgs e)
        {
            this.goBackButton.Focus(FocusState.Programmatic);
        }

        #endregion
        #region Go Back 버튼 클릭시 처리하기 - goBackButton_Click(sender, e)

        /// <summary>
        /// Go Back 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void goBackButton_Click(object sender, RoutedEventArgs e)
        {
            Frame.GoBack();
        }

        #endregion
    }
}